@@ -5,9 +5,7 @@ from factpulse.api.afnorpdppa_api import AFNORPDPPAApi
 from factpulse.api.afnorpdppa_directory_service_api import AFNORPDPPADirectoryServiceApi
 from factpulse.api.afnorpdppa_flow_service_api import AFNORPDPPAFlowServiceApi
 from factpulse.api.chorus_pro_api import ChorusProApi
-from factpulse.api.processing_endpoints_unifis_api import ProcessingEndpointsUnifisApi
 from factpulse.api.sant_api import SantApi
-from factpulse.api.signature_lectronique_api import SignatureLectroniqueApi
 from factpulse.api.traitement_facture_api import TraitementFactureApi
 from factpulse.api.utilisateur_api import UtilisateurApi
 
